==> gtkhtml-0.6.1.tar.gz: gtkhtml-0.6.1/components/html-editor/link.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/* This file is part of the GtkHTML library

   Copyright (C) 2000 Helix Code, Inc.
   Authors:           Radek Doulik (rodo@helixcode.com)

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHcANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#ifndef _GTK_HTML_LINK_H_
#define _GTK_HTML_LINK_H_

typedef struct _GtkHTMLLinkDialog GtkHTMLLinkDialog;

#include <gnome.h>
#include <htmllinktextmaster.h>
#include "control-data.h"

GtkHTMLLinkDialog * gtk_html_link_dialog_new     (GtkHTML *html);
void                gtk_html_link_dialog_destroy (GtkHTMLLinkDialog *);

void                link_insert                  (GtkHTMLControlData *cd);
void                link_edit                    (GtkHTMLControlData *cd, HTMLLinkTextMaster *link);

GtkWidget             * link_properties      (GtkHTMLControlData *cd, gpointer *set_data);
void                    link_apply_cb        (GtkHTMLControlData *cd, gpointer  get_data);
void                    link_close_cb        (GtkHTMLControlData *cd, gpointer  get_data);

#endif

==> gtkhtml_1.1.10.orig.tar.gz: gtkhtml-1.1.10/components/html-editor/link.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/* This file is part of the GtkHTML library

   Copyright (C) 2000 Helix Code, Inc.
   Authors:           Radek Doulik (rodo@helixcode.com)

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHcANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#ifndef _GTK_HTML_LINK_H_
#define _GTK_HTML_LINK_H_

#include <gnome.h>
#include "control-data.h"

GtkWidget             * link_properties      (GtkHTMLControlData *cd, gpointer *set_data);
GtkWidget             * link_insert          (GtkHTMLControlData *cd, gpointer *set_data);
void                    link_insert_cb       (GtkHTMLControlData *cd, gpointer  get_data);
void                    link_apply_cb        (GtkHTMLControlData *cd, gpointer  get_data);
void                    link_close_cb        (GtkHTMLControlData *cd, gpointer  get_data);

#endif
